@@ -10,7 +10,7 @@ use Carp qw/carp/;
 
 =head1 NAME
 
-Test::Exception::LessClever - Test::Exception simplified ***DEPRECATED***
+Test::Exception::LessClever - Test::Exception simplified ***(DEPRECATED)***
 
 =head1 DESCRIPTION
 
@@ -59,7 +59,7 @@ our @EXPORT_OK = qw/live_or_die/;
 our @EXPORT = qw/lives_ok dies_ok throws_ok lives_and/;
 our @CARP_NOT = ( __PACKAGE__ );
 our $TB = Test::Builder->new;
-our $VERSION = "0.007";
+our $VERSION = "0.008";
 
 =item $status = live_or_die( sub { ... }, $name )
 
